@@ -2,9 +2,11 @@
    
    Flexbar - flexible barcode and adapter removal
    
-   Version 3.0.3
+   Version 3.4.0
    
-   uses SeqAn library release 2.2.0
+   BSD 3-Clause License
+   
+   uses SeqAn library release 2.4.0
    and TBB library 4.0 or later
    
    
@@ -27,8 +29,8 @@ int main(int argc, const char* argv[]){
 	using namespace std;
 	using namespace seqan;
 	
-	const string version = "3.0.3";
-	const string date    = "May 2017";
+	const string version = "3.4.0";
+	const string date    = "June 2018";
 	
 	ArgumentParser parser("flexbar");
 	
